<?php

/**
 * Istantiate aa_options
 */
new aa_options;

/**
 * Class aa_options
 */
class aa_options {
	
	private $options;
	private $fonts;
	
	function __construct () {
		
		// Register the form setting for our options array.
		add_action( 'admin_menu', array(&$this, 'init') );
		// Change the capability required to save our options group.
		add_filter( 'option_page_capability_'.TXTDOM.'_options', array(&$this, 'edit_capability') );
		// Add our theme options page to the admin menu.
		add_action( 'admin_menu', array(&$this, 'add_page') );
		// Add custom CSS and Javascript
		add_action( 'admin_enqueue_scripts', array(&$this, 'enqueue_scripts') );
		
	}
	
	function init () {
		
		// If we have no options in the database, let's add them now.
		if ( false === ($this->options = $this->get_theme_options()) )
			add_option( TXTDOM.'_theme_options', $this->options = $this->default_theme_options() );
	
		register_setting(
			TXTDOM.'_options',       // Options group, see settings_fields() call in twentyeleven_theme_options_render_page()
			TXTDOM.'_theme_options', // Database option, see twentyeleven_get_theme_options()
			array(&$this, 'theme_options_validate') // The sanitization callback, see twentyeleven_theme_options_validate()
		);
	
		// Register our settings field groups
		add_settings_section(
			'general', // Unique identifier for the settings section
			'', // Section title (we don't want one)
			'__return_false', // Section callback (we don't want anything)
			'theme_options' // Menu slug, used to uniquely identify the page
		);
	
		// Register our individual settings fields
		// General section
		add_settings_field(
			'col1',  // Unique identifier for the field for this section
			'Colore principale', // Setting field label
			array(&$this, 'color_col1'), // Function that renders the settings field
			'theme_options', // Menu slug, used to uniquely identify the page
			'general' // Settings section. Same as the first argument in the add_settings_section() above
		);
		add_settings_field('bio', 'Bio autore', array(&$this, 'bio_field'), 'theme_options', 'general');
		add_settings_field('copyrightArea', 'Piè di pagina', array(&$this, 'copyrightArea_field'), 'theme_options', 'general');
		add_settings_field('albo', 'Albo Pretorio', array(&$this, 'albo_field'), 'theme_options', 'general');
		add_settings_field('avcp', 'AVCP', array(&$this, 'avcp_field'), 'theme_options', 'general');
		
		// Load default values

	} // init
	
	function enqueue_scripts ( $hook ) {
		
		if( 'appearance_page_theme_options' != $hook )
			return;
		wp_enqueue_script( TXTDOM.'_theme_options_js', get_template_directory_uri() . '/inc/theme-options/theme-options.js', array('jquery', 'wp-color-picker') );
		wp_enqueue_style( TXTDOM.'_theme_options_css', get_template_directory_uri() . '/inc/theme-options/theme-options.css', array('wp-color-picker') );
		
	} // enqueue_scripts
	
	function edit_capability () {
		
		return 'edit_theme_options';
		
	} // edit_capability
	
	function default_theme_options () {
		
		return array(
			'copyrightArea' => '<p>Amministrazione Accessibile – Sviluppato da <a href="http://www.spaziosputnik.it">Spazio Sputnik</a> – Basato su <a href="http://getbootstrap.com">Bootstrap 3</a></p>',
			'col1'          => '#428BCA',
			'bio'           => '',
			'albo'          => 1,
			'avcp'          => 1
		);
	
	} // default_theme_options
	
	function get_theme_options () {
		
		return get_option( TXTDOM.'_theme_options', $this->default_theme_options() );
		
	} // get_theme_options
	
	function add_page () {
		
		add_theme_page(
			__( 'Opzioni del Tema', 'amm-accessibile' ),	// Name of page
			__( 'Opzioni Tema', 'amm-accessibile' ),		// Label in menu
			'edit_theme_options',								// Capability required
			'theme_options',										// Menu slug, used to uniquely identify the page
			array(&$this, 'theme_options_render_page')	// Function that renders the options page
		);
	
	} // add_page
	
	function theme_options_render_page () {
			
		// if settings updated save the custom style 
		if(isset($_GET['settings-updated']) && $_GET['settings-updated'])
			$this->_save();
		
		?>
		<div class="wrap">
			<h2>
				<?php printf( '%s - Opzioni Tema', wp_get_theme() ); ?>
			</h2>
			<?php settings_errors(); ?>
			
			<h3 class="nav-tab-wrapper">
				<a class="nav-tab" href="#general"> Opzioni generali </a>
			</h3>
						
			<form method="post" action="options.php" enctype="multipart/form-data">
				<?php
					settings_fields( TXTDOM.'_options' );
					do_settings_sections( 'theme_options' );
					submit_button();
				?>
			</form>
		</div>
		<?php
		
	} // theme_options_render_page

	private function _save() {
		extract( get_option( TXTDOM.'_theme_options' ) );
		require dirname(__FILE__).'/../style-custom.tpl.php';
		update_option( TXTDOM.'_style_custom', $style );
	} // save

	function theme_options_validate( $input ) {

		$output = $this->default_theme_options();
		
		// Simple fields
		$fields = array('copyrightArea', 'bio');
		for($i=1; $i<5;$i++) $fields []= "col$i";
		foreach($fields as $f)
			if ( isset( $input[$f] ) )
				$output[$f] = $input[$f];
		// Checkboxes
		$checkboxes = array('albo', 'avcp');
		foreach($checkboxes as $c)
			if( !isset($input[$c]) )
				$output[$c] = 0;
		
		// End
		return $this->options = $output;

	} // theme_options_validate
	
	function copyrightArea_field () {
		
		?>
		<textarea class="all-options large-text code" name="<?php echo TXTDOM; ?>_theme_options[copyrightArea]" id="copyrightArea" rows="4"><?php echo esc_attr( $this->options['copyrightArea'] ); ?></textarea>
		<?php
		
	} // copyrightArea_field

	function bio_field () {
		
		?>
		<input type="checkbox" name="<?php echo TXTDOM; ?>_theme_options[bio]" value="1" <?php checked( $this->options['bio'], 1 ); ?> />
		Spunta la casella per visualizzare il blocco di informazioni biografiche dell'autore al fondo degli articoli.
		<?php
		
	} // bio_field

	function albo_field () {
		
		?>
		<input type="checkbox" name="<?php echo TXTDOM; ?>_theme_options[albo]" value="1" <?php checked( $this->options['albo'], 1 ); ?> />
		Spunta la casella per utilizzare la versione personalizzata del plugin "Albo Pretorio" per questo tema.
		<?php
		
	} // bio_field

	function avcp_field () {
		
		?>
		<input type="checkbox" name="<?php echo TXTDOM; ?>_theme_options[avcp]" value="1" <?php checked( $this->options['avcp'], 1 ); ?> />
		Spunta la casella per utilizzare la versione personalizzata del plugin "AVCP" per questo tema.
		<?php
		
	} // bio_field

	private function _colorField ( $name ) {
		
		?>
		<input type="text" value="<?php echo esc_attr( $this->options[$name] ); ?>" class="colorField" name="<?php echo TXTDOM; ?>_theme_options[<?php echo $name; ?>]" />
		<?php
		
	} // _colorField
	
	function __call ( $name, $args ) {
		
		// if is a color call the _colorField function
		if(!strncmp($name, 'color_', strlen('color_')))
			$this->_colorField(substr($name, strlen('color_')));

	} // __call
	
}
