<?php

class AA_Links_Widget extends WP_Widget {

	private $icone;

	function __construct() {
		parent::__construct(
	 		'AA_links_widget', // Base ID
			'AA > Link', // Name
			array( 'description' => 'Collegamenti personalizzabili | Amministrazione Accessibile' ) // Args
		);
		add_action( 'admin_enqueue_scripts', array(__CLASS__, 'font_awesome') );
		add_action( 'admin_footer-widgets.php', array(&$this, 'js') );
		add_action( 'admin_print_styles-widgets.php', array(&$this, 'css') );
	}

	function widget( $args, $instance ) {
		extract($args);
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$links = empty($instance['links']) ? array() : $instance['links'];

		echo $before_widget;

		if ( !empty($title) )
			echo $before_title . $title . $after_title;
		?>

		<ul class="link-widget list-group">		
			<?php foreach ($links as $l): ?>
				<li class="list-group-item">
					<a href="<?php echo $l['url']; ?>">
						<?php if($l['icon']): ?><i class="fa fa-<?php echo $l['icon']; ?> fa-fw"></i><?php endif; ?><?php echo $l['title']; ?>
					</a>
				</li>
			<?php endforeach; ?>
		</ul>
		
		<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);

		$instance['links'] = array();
		if ( isset ( $new_instance['links'] ) ) {
			$i = 0;
			foreach ( $new_instance['links'] as $l ) {
				$instance['links'][$i]['icon'] = $l['icon'];
				$instance['links'][$i]['title'] = strip_tags($l['title']);
				$instance['links'][$i]['url'] = esc_url($l['url']);
				$i++;
			}
		}

		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'links' => array() ) );
		$title = esc_attr($instance['title']);
		$links = $instance['links'];
		$this->icone = $this->_get_icone();
		?>

		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
		</p>

		<div class="linkcustomizzati">
			<?php foreach ($links as $k => $l): ?>				
				<div class="linkcustomizzato postbox">
					<p class="alignright"><a href="javascript:;" class="del">Rimuovi</a></p>
					<p>
						<label>Icona:</label>&nbsp;
						<?php $this->makeSelect($k, $l['icon']); ?>
					</p>
					<p>
						<label>Titolo:</label>
						<input type="text" class="widefat" name="<?php echo $this->get_field_name( 'links' ); ?>[<?php echo $k; ?>][title]" value="<?php echo $l['title']; ?>" />
					</p>
					<p>
						<label>URL:</label>
						<input type="text" class="widefat" name="<?php echo $this->get_field_name( 'links' ); ?>[<?php echo $k; ?>][url]" value="<?php echo $l['url']; ?>" />
					</p>
				</div>
			<?php endforeach; ?>
		</div>

		<p><a href="javascript:;" class="addCustomLink button">Aggiungi link</a></p>

		<!-- template -->
		<script type="text/html" class="linkcustomizzatotpl">
			<div class="linkcustomizzato postbox">
				<p class="alignright"><a href="javascript:;" class="del">Rimuovi</a></p>
				<p>
					<label>Icona:</label>&nbsp;
					<?php $this->makeSelect(999); ?>
				</p>
				<p>
					<label>Titolo:</label>
					<input type="text" class="widefat" name="<?php echo $this->get_field_name( 'links' ) . '[999][title]'; ?>" />
				</p>
				<p>
					<label>URL:</label>
					<input type="text" class="widefat" name="<?php echo $this->get_field_name( 'links' ) . '[999][url]'; ?>" />
				</p>
			</div>
		</script>

		<?php
	}

	function makeSelect ( $index, $value = '' ) {
		$id = $this->get_field_id( 'links' ) . "[$index][icon]";
		$name = $this->get_field_name( 'links' ) . "[$index][icon]";
		?>
		
		<select name="<?php echo $name; ?>" id="<?php echo $id; ?>" style="font-family:FontAwesome">
			<option></option>
			<?php foreach ($this->icone as $char => $icon): ?>
				<option value="<?php echo $icon; ?>" <?php selected( $value, $icon ); ?>>&#x<?php echo $char; ?></option>
			<?php endforeach; ?>
		</select>

		<?php
	}

	static function font_awesome( $hook ) {
		if( 'widgets.php' != $hook )
			return;
		wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/font/font-awesome.min.css' );
	}

	function js () {
		?>
		
		<script type="text/javascript">
			(function($){ $(document).ready(function(){
			
				$(document).on('click', '.linkcustomizzato .del', function(){
					if(confirm('Sei sicuro di voler rimuovere il link?'))
						$(this).closest('.linkcustomizzato').remove();
				});

				$(document).on('click', '.addCustomLink', function(){
					var $linksociali = $(this).parent().prev();
					var countLinks = $linksociali.children('.linkcustomizzato').length;
					var $tpl = $(this).closest('.widget-content').find('.linkcustomizzatotpl').first();
					$linksociali.append($tpl.html().replace(/999/g, countLinks));
				});
			
			}); })(jQuery);
		</script>

		<?php
	}

	function css () {
		?>

		<style>
			.linkcustomizzato { padding: 6px !important; }
		</style>

		<?php
	}

	private function _get_icone () {
		WP_Filesystem();
		global $wp_filesystem;
		return json_decode($wp_filesystem->get_contents(get_template_directory().'/inc/font-awesome-icone.json'));
	}

}