<?php

class AA_Social_Links_Widget extends WP_Widget {

	static private $socialIcons = array(
		'&#xf09a' => 'facebook',
		'&#xf082' => 'facebook-square',
		'&#xf16e' => 'flickr',
		'&#xf180' => 'foursquare',
		'&#xf099' => 'twitter'
	);

	function __construct() {
		parent::__construct(
	 		'AA_social_links_widget', // Base ID
			'AA > Social Link', // Name
			array( 'description' => 'Collegamenti alle proprie pagine nei social network | Amministrazione Accessibile' ) // Args
		);
		add_action( 'admin_enqueue_scripts', array(__CLASS__, 'font_awesome') );
		add_action( 'admin_footer-widgets.php', array(&$this, 'js') );
		add_action( 'admin_print_styles-widgets.php', array(&$this, 'css') );
	}

	function widget( $args, $instance ) {
		extract($args);
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$social = empty($instance['social']) ? array() : $instance['social'];

		echo $before_widget;

		if ( !empty($title) )
			echo $before_title . $title . $after_title;
		?>

		<div class="social-link-widget panel-body">
			<?php foreach ($social as $s): ?>
				<a href="<?php echo $s['url']; ?>" class="btn btn-default">
					<i class="fa fa-<?php echo $s['icon']; ?>"></i> <?php echo $s['title']; ?>
				</a>
			<?php endforeach; ?>
		</div>
		
		<?php
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);

		$instance['social'] = array();
		if ( isset ( $new_instance['social'] ) ) {
			$i = 0;
			foreach ( $new_instance['social'] as $s ) {
				$instance['social'][$i]['icon'] = $s['icon'];
				$instance['social'][$i]['title'] = strip_tags($s['title']);
				$instance['social'][$i]['url'] = esc_url($s['url']);
				$i++;
			}
		}

		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'social' => array() ) );
		$title = esc_attr($instance['title']);
		$social = $instance['social'];
		?>

		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
		</p>

		<div class="linksociali">
			<?php foreach ($social as $k => $s): ?>				
				<div class="linksociale postbox">
					<p class="alignright"><a href="javascript:;" class="del">Rimuovi</a></p>
					<p>
						<label>Icona:</label>&nbsp;
						<?php $this->makeSelect($k, $s['icon']); ?>
					</p>
					<p>
						<label>Titolo:</label>
						<input type="text" class="widefat" name="<?php echo $this->get_field_name( 'social' ); ?>[<?php echo $k; ?>][title]" value="<?php echo $s['title']; ?>" />
					</p>
					<p>
						<label>URL:</label>
						<input type="text" class="widefat" name="<?php echo $this->get_field_name( 'social' ); ?>[<?php echo $k; ?>][url]" value="<?php echo $s['url']; ?>" />
					</p>
				</div>
			<?php endforeach; ?>
		</div>

		<p><a href="javascript:;" class="addLinkSociale button">Aggiungi social link</a></p>

		<!-- template -->
		<script type="text/html" class="linksocialetpl">
			<div class="linksociale postbox">
				<p class="alignright"><a href="javascript:;" class="del">Rimuovi</a></p>
				<p>
					<label>Icona:</label>&nbsp;
					<?php $this->makeSelect(999); ?>
				</p>
				<p>
					<label>Titolo:</label>
					<input type="text" class="widefat" name="<?php echo $this->get_field_name( 'social' ) . '[999][title]'; ?>" />
				</p>
				<p>
					<label>URL:</label>
					<input type="text" class="widefat" name="<?php echo $this->get_field_name( 'social' ) . '[999][url]'; ?>" />
				</p>
			</div>
		</script>

		<?php
	}

	function makeSelect ( $index, $value = '' ) {
		$id = $this->get_field_id( 'social' ) . "[$index][icon]";
		$name = $this->get_field_name( 'social' ) . "[$index][icon]";
		?>
		
		<select name="<?php echo $name; ?>" id="<?php echo $id; ?>" style="font-family:FontAwesome">
			<?php foreach (self::$socialIcons as $char => $icon): ?>
				<option value="<?php echo $icon; ?>" <?php selected( $value, $icon ); ?>><?php echo $char; ?></option>
			<?php endforeach; ?>
		</select>

		<?php
	}

	static function font_awesome( $hook ) {
		if( 'widgets.php' != $hook )
			return;
		wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/font/font-awesome.min.css' );
	}

	function js () {
		?>
		
		<script type="text/javascript">
			(function($){ $(document).ready(function(){
			
				$(document).on('click', '.linksociale .del', function(){
					if(confirm('Sei sicuro di voler rimuovere il social link?'))
						$(this).closest('.linksociale').remove();
				});

				$(document).on('click', '.addLinkSociale', function(){
					var $linksociali = $(this).parent().prev();
					var countLinks = $linksociali.children('.linksociale').length;
					var $tpl = $(this).closest('.widget-content').find('.linksocialetpl').first();
					$linksociali.append($tpl.html().replace(/999/g, countLinks));
				});
			
			}); })(jQuery);
		</script>

		<?php
	}

	function css () {
		?>

		<style>
			.linksociale { padding: 6px !important; }
		</style>

		<?php
	}

}