/*
 * Chris Rodriguez
 * chris@inathought.com
*/

// Cookie handler, non-jQuery style
function createCookie(name, value, days) {
	if (days) {
        var date = new Date();
        date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
        var expires = "; expires=" + date.toGMTString();
	} else
	var expires = "";
	document.cookie = name + "=" + value + expires + "; path=/";
}
	
function readCookie(name) {
	var nameEQ = name + "=";
	var ca = document.cookie.split(';');
	for(var i = 0; i < ca.length; i++) {
        var c = ca[i];
        while (c.charAt(0) == ' ') c = c.substring(1, c.length);
        if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length, c.length);
	}
	return null;
}
	
function eraseCookie(name) {
	// createCookie(name, "", -1);
	createCookie(name, "");
}


(function($){  $(document).ready(function(){

	// Prepend our toolbar to the left side of the page, right under <body>
	var a11y_toolbar =
		'<!-- a11y toolbar -->' +
			'<div class="a11y-toolbar pull-left">' +
				'<ul>' +
					'<li><a href="#" class="a11y-toggle-contrast toggle-contrast" id="is_normal_contrast" title="Passa ad alto contrasto"><span class="hidden">Passa ad alto contrasto</span><i class="fa fa-adjust"></i></a></li>' +
					'<li><a href="#" class="a11y-toggle-fontsize toggle-fontsize" id="is_normal_fontsize" title="Aumenta dimensione testo"><span class="hidden">Cambia dimensione testo</span><i class="fa fa-font"></i></a></li>' +
				'</ul>' +
			'</div>' +
		'<!-- // a11y toolbar -->';
	$('#wrap').prepend(a11y_toolbar);

	var ally_path = $('#aa-style-css').attr('href');
	ally_path = ally_path.substring(0, ally_path.lastIndexOf("/")) + '/js/a11y-toolbar/css';

	function append_ally_link(css, id) {
		$('head').append('<link rel="stylesheet" href="'+ally_path+'/a11y-'+css+'.css" type="text/css" id="'+id+'" />');
	}

	// Saturation handler
	if (readCookie('a11y-desaturated')) {
		append_ally_link('desaturate', 'desaturatedStylesheet');
		$('#is_normal_color').attr('id', 'is_grayscale').addClass('active');
	}

	$('.toggle-grayscale').on('click', function() {
		if ($(this).attr('id') == "is_normal_color") {
			append_ally_link('desaturate', 'desaturatedStylesheet');
			$(this).attr('id', 'is_grayscale').addClass('active');
			createCookie('a11y-desaturated', '1');
			return false;
		} else {
			$('#desaturatedStylesheet').remove();
			$(this).attr('id', 'is_normal_color').removeClass('active');
			eraseCookie('a11y-desaturated');
			return false;
		}
	});

	// Contrast handler
	if (readCookie('a11y-high-contrast')) {
		append_ally_link('contrast', 'highContrastStylesheet');
		$('#is_normal_contrast').attr('id', 'is_high_contrast').addClass('active').attr('title', 'Passa a versione predefinita');
		$('.a11y-toolbar i').addClass('fa-inverse');
	}

	$('.toggle-contrast').on('click', function() {
		if ($(this).attr('id') == "is_normal_contrast") {
			append_ally_link('contrast', 'highContrastStylesheet');
			$(this).attr('id', 'is_high_contrast').addClass('active').attr('title', 'Passa a versione predefinita');
			$(this).closest('.a11y-toolbar').find('i').addClass('fa-inverse');
			createCookie('a11y-high-contrast', '1');
			return false;
		} else {
			$('#highContrastStylesheet').remove();
			$(this).attr('id', 'is_normal_contrast').removeClass('active').attr('title', 'Passa ad alto contrasto');
			$(this).closest('.a11y-toolbar').find('i').removeClass('fa-inverse');
			eraseCookie('a11y-high-contrast');
			return false;
		}
	});

	// Fontisze handler
	if (readCookie('a11y-larger-fontsize')) {
		append_ally_link('fontsize', 'largerFontsizeStylesheet');
		$('#is_normal_fontsize').attr('id', 'is_large_fontsize').addClass('active').attr('title', 'Diminuisci dimensione testo');
	}

	$('.toggle-fontsize').on('click', function() {
		if ($(this).attr('id') == "is_normal_fontsize") {
			append_ally_link('fontsize', 'largerFontsizeStylesheet');
			$(this).attr('id', 'is_large_fontsize').addClass('active').attr('title', 'Diminuisci dimensione testo');
			createCookie('a11y-larger-fontsize', '1');
			return false;
		} else {
			$('#largerFontsizeStylesheet').remove();
			$(this).attr('id', 'is_normal_fontsize').removeClass('active').attr('title', 'Aumenta dimensione testo');
			eraseCookie('a11y-larger-fontsize');
			return false;
		}
	});

	// Sets a -1 tabindex to ALL sections for .focus()-ing
	var sections = document.getElementsByTagName("section");
	for (var i = 0, max = sections.length; i < max; i++) {
		sections[i].setAttribute('tabindex', -1);
		sections[i].className += ' focusable';
	}

	// If there is a '#' in the URL (someone linking directly to a page with an anchor), go directly to that area and focus is
	// Thanks to WebAIM.org for this idea
	if (document.location.hash) {
		var anchorUponArrival = document.location.hash;
		setTimeout(function() {
			// $(anchorUponArrival).Scrollto({ duration: 1000 });
			$(anchorUponArrival).focus();
		}, 100);
	}

	// Focuses on the correct section of the page if we're page linking
	// Thanks to WebAIM.org for this idea
	$('a[href^="#"]').click(function(event) {
		var inPageAnchor = "#" + this.href.split('#')[1];
		// $(inPageAnchor).ScrollTo({ duration: 1000 });
		setTimeout(function() {
			$(inPageAnchor).focus();
		}, 100);
		return false;
	});
}); })(jQuery);
